Set Transformers
----------------
The ``mi_module_zoo.settransformer`` contains implementations of
transformer-based models that process sets.

.. autoclass:: mi_module_zoo.settransformer.SetTransformer
   :members: forward
   :undoc-members:

.. autoclass:: mi_module_zoo.settransformer.ISAB
   :members: forward
   :undoc-members:

.. autoclass:: mi_module_zoo.settransformer.PMA
   :members: forward
   :undoc-members:

.. autoclass:: mi_module_zoo.settransformer.MultiheadInitType
   :members:
   :undoc-members:
